__author__ = "Nico Schlömer"
__author_email__ = "nico.schloemer@gmail.com"
__copyright__ = "Copyright (C) 2016-2019 {} <{}>".format(__author__, __author_email__)
__license__ = "License :: OSI Approved :: MIT License"
__version__ = "0.5.0"
__maintainer__ = "Nico Schlömer"
__status__ = "Development Status :: 4 - Beta"
__url__ = "https://github.com/nschloe/pygalmesh"
